python pitayaserver
====================

This lib helps creating pitaya backend servers using python.

### Installing

pip install pitayaserver

### Usage

See python-example folder in root directory
